@@ -37,24 +37,9 @@ typedef struct {
 typedef chart_line *chart_ln;
 typedef GList *chart_lnlist;
 
-
 typedef struct {
-  char type;
-  double val, a_min, a_max, zm_min, zm_max;
-  int priority;
-  char wide;
-} plot_definition;
-
-enum {LBL_NE, LBL_SE, LBL_SW, LBL_NW};
-
-typedef struct {
-  char type;
-  double re, im;
-  char pos;
-} label_definition;
-
-typedef struct {
-  double f, r, x;
+  double f, r, x, nb_r, nb_c;
+  char nb_ext;
   chart_pt pt;
 } load_definition;
 
